==> bootstrap-0.104-test-sources.jar: io/airlift/bootstrap/ExecutedInstance.java <==
/*
 * Copyright 2010 Proofpoint, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.airlift.bootstrap;

import com.google.inject.Inject;

import java.util.concurrent.CountDownLatch;

public class ExecutedInstance extends Executed
{
    private final CountDownLatch startLatch = new CountDownLatch(1);
    private final CountDownLatch endLatch = new CountDownLatch(1);

    @Inject
    public ExecutedInstance()
    {
    }

    public void waitForStart()
            throws InterruptedException
    {
        startLatch.await();
    }

    public void waitForEnd()
            throws InterruptedException
    {
        endLatch.await();
    }

    @Override
    public void run()
    {
        TestLifeCycleManager.note("Starting");
        startLatch.countDown();

        try {
            if (!Thread.interrupted()) {
                try {
                    Thread.sleep(Integer.MAX_VALUE);
                }
                catch (InterruptedException e) {
                    Thread.currentThread().interrupt();
                }
            }
        }
        finally {
            TestLifeCycleManager.note("Done");
            endLatch.countDown();
        }
    }
}

==> bootstrap-0.115-test-sources.jar: io/airlift/bootstrap/ExecutedInstance.java <==
/*
 * Copyright 2010 Proofpoint, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.airlift.bootstrap;

import com.google.inject.Inject;

import java.util.concurrent.CountDownLatch;

public class ExecutedInstance
        extends Executed
{
    private final CountDownLatch startLatch = new CountDownLatch(1);
    private final CountDownLatch endLatch = new CountDownLatch(1);

    @Inject
    public ExecutedInstance()
    {
    }

    public void waitForStart()
            throws InterruptedException
    {
        startLatch.await();
    }

    public void waitForEnd()
            throws InterruptedException
    {
        endLatch.await();
    }

    @Override
    public void run()
    {
        TestLifeCycleManager.note("Starting");
        startLatch.countDown();

        try {
            if (!Thread.interrupted()) {
                try {
                    Thread.sleep(Integer.MAX_VALUE);
                }
                catch (InterruptedException e) {
                    Thread.currentThread().interrupt();
                }
            }
        }
        finally {
            TestLifeCycleManager.note("Done");
            endLatch.countDown();
        }
    }
}
